#include <array.au3>
#include <date.au3>
#include "XMLWrapperEx.au3"


;~ _Example_1__XML_SelectNodes()
;~ _Example_2__XML_CreateChildWAttr()
;~ _Example_3__XML_Misc_ErrorParser()
;~ _Example_MSDN_1__setAttributeNode()



Func _Example_1__XML_SelectNodes()
	_XML_MiscProperty_NotifyAll(True)
	_XML_MiscProperty_NotifyToMsgBox(False)

	Global $oErrorHandler = ObjEvent("AutoIt.Error", "_ErrFunc_CustomUserHandler")

	; Add user ComError handler ; it will be used toogether with internal ComError handler
	_XML_ComErrorHandler_UserFunction(_ErrFunc_CustomUserHandler)

	$sXmlFile = @ScriptDir & "\XML_Example_XML_Files\MSDN\books.xml"
	$oXmlDoc = _XML_Load($sXmlFile)
	_XML_ErrorParser($oXmlDoc)
	MsgBox($MB_SYSTEMMODAL + $MB_ICONINFORMATION, '_Example_1__XML_SelectNodes', _XML_TIDY($oXmlDoc))

	Local $oNodesColl = _XML_SelectNodes($oXmlDoc, "//price")
	Local $aNodesColl = _XML_Array_GetNodeList($oNodesColl)
	_ArrayDisplay($aNodesColl, '_Example_1__XML_SelectNodes : ' & _XML_GetNodeCount($oXmlDoc, "//price"))

EndFunc   ;==>_Example_1__XML_SelectNodes

Func _Example_2__XML_CreateChildWAttr()
	_XML_MiscProperty_NotifyAll(True)
	_XML_MiscProperty_NotifyToMsgBox(False)

	Global $oErrorHandler = ObjEvent("AutoIt.Error", "_ErrFunc_CustomUserHandler")

	; Add user ComError handler ; it will be used toogether with internal ComError handler
	_XML_ComErrorHandler_UserFunction(_ErrFunc_CustomUserHandler)

	$sXmlFile = @ScriptDir & "\XML_Example_XML_Files\MSDN\books.xml"
	$oXmlDoc = _XML_Load($sXmlFile)
	_XML_ErrorParser($oXmlDoc)
	MsgBox($MB_SYSTEMMODAL + $MB_ICONINFORMATION, 'Before _Example_2__XML_CreateChildWAttr()', _XML_TIDY($oXmlDoc))


	Local $aAttributeList[2][2] = [['Fist', '1'], ['Second', '2']]
	_XML_CreateChildWAttr($oXmlDoc, "//book", 'MyNewNode', $aAttributeList, "SomeText")

	; TIDY xml and save result back to object
	MsgBox($MB_SYSTEMMODAL + $MB_ICONINFORMATION, 'After _Example_2__XML_CreateChildWAttr()', _XML_TIDY($oXmlDoc))
	$oXmlDoc.loadXML(_XML_TIDY($oXmlDoc))
	_XML_Misc_Viewer($oXmlDoc)

EndFunc   ;==>_Example_2__XML_CreateChildWAttr

Func _Example_3__XML_Misc_ErrorParser()
	_XML_MiscProperty_NotifyAll(True)
	_XML_MiscProperty_NotifyToMsgBox(False)

	Global $oErrorHandler = ObjEvent("AutoIt.Error", "_ErrFunc_CustomUserHandler")

	; Add user ComError handler ; it will be used toogether with internal ComError handler
	_XML_ComErrorHandler_UserFunction(_ErrFunc_CustomUserHandler)

	$sXmlFile = @ScriptDir & "\XML_Example_XML_Files\MSDN\books.xml"
	$oXmlDoc = _XML_Load($sXmlFile)
	_XML_ErrorParser($oXmlDoc)
	Local $oNodesColl = _XML_SelectNodes($oXmlDoc, "/1/price")
	#forceref $oNodesColl
	If @error then
		MsgBox($MB_SYSTEMMODAL + $MB_ICONINFORMATION, '_XML_Misc_ErrorParser', _XML_Misc_ErrorParser(@error))
	EndIf


EndFunc   ;==>_Example_2__XML_CreateChildWAttr

Func _Example_MSDN_1__setAttributeNode()
	_XML_MiscProperty_NotifyAll(True)
	_XML_MiscProperty_NotifyToMsgBox(False)

	Global $oErrorHandler = ObjEvent("AutoIt.Error", "_ErrFunc_CustomUserHandler")

	; Add user ComError handler ; it will be used toogether with internal ComError handler
	_XML_ComErrorHandler_UserFunction(_ErrFunc_CustomUserHandler)

	$sXmlFile = @ScriptDir & "\XML_Example_XML_Files\MSDN\books.xml"
	$oXmlDoc = _XML_Load($sXmlFile)
	_XML_ErrorParser($oXmlDoc)
	MsgBox($MB_SYSTEMMODAL + $MB_ICONINFORMATION, '_Example_MSDN_1__setAttributeNode', _XML_TIDY($oXmlDoc))

	;MSDN; https://msdn.microsoft.com/en-us/library/ms762235(v=vs.85).aspx

	;MSDN; nodePublishDate = xmlDoc.createAttribute("PublishDate");
	Local $oNodePublishDate = $oXmlDoc.createAttribute("PublishDate");

	; Checking
	MsgBox($MB_SYSTEMMODAL + $MB_ICONINFORMATION, 'Temp', _XML_TIDY($oXmlDoc)) ; Hmmm... Nothing happend

	;MSDN; nodePublishDate.value = String(Date());
	$oNodePublishDate.value = String(_Now());

	;MSDN; nodeBook = xmlDoc.selectSingleNode("//book");
	Local $oNodeBook = $oXmlDoc.selectSingleNode("//book");

	;MSDN; nodeBook.setAttributeNode(nodePublishDate);
	$oNodeBook.setAttributeNode($oNodePublishDate);

	;MSDN; WScript.Echo(nodeBook.getAttribute("PublishDate"));
	ConsoleWrite($oNodeBook.getAttribute("PublishDate") & @CRLF)

	MsgBox($MB_SYSTEMMODAL + $MB_ICONINFORMATION, 'Result', _XML_TIDY($oXmlDoc))

EndFunc   ;==>_Example_MSDN_1__setAttributeNode

Func _ErrFunc_CustomUserHandler($oError)
	ConsoleWrite(@ScriptName & " (" & $oError.scriptline & ") : ==> COM Error intercepted !" & @CRLF & _
			@TAB & "err.number is: " & @TAB & @TAB & "0x" & Hex($oError.number) & @CRLF & _
			@TAB & "err.windescription:" & @TAB & $oError.windescription & @CRLF & _
			@TAB & "err.description is: " & @TAB & $oError.description & @CRLF & _
			@TAB & "err.source is: " & @TAB & @TAB & $oError.source & @CRLF & _
			@TAB & "err.helpfile is: " & @TAB & $oError.helpfile & @CRLF & _
			@TAB & "err.helpcontext is: " & @TAB & $oError.helpcontext & @CRLF & _
			@TAB & "err.lastdllerror is: " & @TAB & $oError.lastdllerror & @CRLF & _
			@TAB & "err.scriptline is: " & @TAB & $oError.scriptline & @CRLF & _
			@TAB & "err.retcode is: " & @TAB & "0x" & Hex($oError.retcode) & @CRLF & @CRLF)
EndFunc   ;==>_ErrFunc_CustomUserHandler
